==> haskell-type-errors-pretty-0.0.1.2-121-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-type-errors-pretty.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 type-errors-pretty
version:              0.0.1.2
visibility:           public
id:                   type-errors-pretty-0.0.1.2-7qqSO1lpJOF2ehYHBd6sqC
key:                  type-errors-pretty-0.0.1.2-7qqSO1lpJOF2ehYHBd6sqC
license:              MPL-2.0
copyright:
    2019-2020 Dmitrii Kovanikov
    2020-2021 Kowainik

maintainer:
    Dmitrii Kovanikov <kovanikov@gmail.com>
    Kowainik <xrom.xkov@gmail.com>

author:               Dmitrii Kovanikov
homepage:             https://github.com/kowainik/type-errors-pretty
synopsis:             Combinators for writing pretty type errors easily
description:
    This library provides replacements for the @ErrorMessage@ constructors to
    write the text of custom error messages easily.

category:             Types, Type Errors
abi:                  9c2e70618e0be10bdd3b35fd5fa5d2d1
exposed:              True
exposed-modules:      Type.Errors.Pretty
import-dirs:          /usr/lib/ghc-9.4.8/site-local/type-errors-pretty-0.0.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/type-errors-pretty-0.0.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/type-errors-pretty-0.0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-type-errors-pretty
hs-libraries:         HStype-errors-pretty-0.0.1.2-7qqSO1lpJOF2ehYHBd6sqC
depends:              base-4.17.2.1
haddock-interfaces:
    /usr/share/doc/haskell-type-errors-pretty/html/type-errors-pretty.haddock

haddock-html:         /usr/share/doc/haskell-type-errors-pretty/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-type-errors-pretty-0.0.1.2-122-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-type-errors-pretty.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 type-errors-pretty
version:              0.0.1.2
visibility:           public
id:                   type-errors-pretty-0.0.1.2-HEv7UtEFbq259IsOfuDZwS
key:                  type-errors-pretty-0.0.1.2-HEv7UtEFbq259IsOfuDZwS
license:              MPL-2.0
copyright:
    2019-2020 Dmitrii Kovanikov
    2020-2021 Kowainik

maintainer:
    Dmitrii Kovanikov <kovanikov@gmail.com>
    Kowainik <xrom.xkov@gmail.com>

author:               Dmitrii Kovanikov
homepage:             https://github.com/kowainik/type-errors-pretty
synopsis:             Combinators for writing pretty type errors easily
description:
    This library provides replacements for the @ErrorMessage@ constructors to
    write the text of custom error messages easily.

category:             Types, Type Errors
abi:                  a97cdaa9d6e43e39c70fd28e6316bf1c
exposed:              True
exposed-modules:      Type.Errors.Pretty
import-dirs:          /usr/lib/ghc-9.4.8/site-local/type-errors-pretty-0.0.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/type-errors-pretty-0.0.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/type-errors-pretty-0.0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-type-errors-pretty
hs-libraries:         HStype-errors-pretty-0.0.1.2-HEv7UtEFbq259IsOfuDZwS
depends:              base-4.17.2.1
haddock-interfaces:
    /usr/share/doc/haskell-type-errors-pretty/html/type-errors-pretty.haddock

haddock-html:         /usr/share/doc/haskell-type-errors-pretty/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
